@@ -6,9 +6,9 @@ import sys
 
 
 def usage(status):
-    '''CLI --help menu'''
+    """ CLI --help menu. """
     args = ['Usage: subtrs [subtitles_file] [destination languages]\n',
-            '       Simple tool that trlanslates video subtitles\n',
+            '       Simple tool that translates video subtitles\n',
             '       Support subtitles files [*.sbv, *.vtt, *.srt]',
             '       Destination languages [en,de,ru] etc.\n',
             'Optional arguments:',
