@@ -13,10 +13,10 @@ from subtrs.__metadata__ import __prog__, __version__
 
 
 class Subtitles:
-    '''A simple tool that tranlates video subtitles'''
+    """ A simple tool that translates video subtitles. """
 
     def __init__(self, args: list, flags: list):
-        '''Initialization'''
+        """ Initialization. """
         self.flags = flags
         self.file = args[0]
         self.dest = args[1].split(',')
@@ -30,7 +30,7 @@ class Subtitles:
         self.translator = Translator()
 
     def color(self):
-        '''Checking color flag'''
+        """ Checking color flag. """
         if "--color" in self.flags:
             self.TRS_COLOR = fore.LIGHT_YELLOW
             self.OUT_COLOR = fore.LIGHT_GREEN
@@ -38,7 +38,7 @@ class Subtitles:
             self.RESET_COLOR = style.RESET
 
     def read_subs(self):
-        '''Read the subtitle file'''
+        """ Read the subtitle file. """
         try:
             with open(self.file, 'r', encoding='utf-8') as subs:
                 self.subs_file = subs.readlines()
@@ -47,9 +47,9 @@ class Subtitles:
             sys.exit(1)
 
     def write_new_subs(self):
-        '''Write the new subtitle file'''
+        """ Write the new subtitle file. """
         for index, lang in enumerate(self.dest, 1):
-            self.Exceptions_dest_lang(lang)
+            self.exceptions_dest_lang(lang)
             self.read_subs()
 
             cap_file = self.file.split('/')[-1]
@@ -86,41 +86,42 @@ class Subtitles:
             self.created_file(new_captions)
 
     def trs_jobs(self, index: int, lang: str):
-        '''View the job title'''
+        """ View the job title. """
         return (f'[{index}/{len(self.dest)}] '
                 f'Translate into {googletrans.LANGUAGES.get(lang)}')
 
     def print_line_in(self, line: str):
-        '''Print line before translated'''
+        """ Print line before translated. """
         print(f'[{self.detect_lang(line)}]{self.IN_COLOR}'
               f' <<{self.RESET_COLOR} {line}')
 
     def print_line_out(self, line: str, lang: str):
-        '''Print line after traslate'''
+        """ Print line after translate. """
         print(f'[{lang}]{self.OUT_COLOR} >> '
               f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
 
     def translate(self, line: str, lang: str):
-        '''Translate line per line'''
+        """ Translate line per line. """
         return self.translator.translate(line, dest=lang).text + '\n'
 
     def detect_lang(self, line: str):
-        '''Identifies the language used'''
+        """ Identifies the language used. """
         return self.translator.detect(line).lang
 
     def created_file(self, file: str):
-        '''Message when the file finished'''
+        """ Message when the file finished. """
         if self.file_exist(file):
             print(f"Subtitle file '{file}' created.")
         else:
             print(f"Subtitle file '{file}' does not exist.")
 
-    def file_exist(self, file: str):
-        '''Check if the file exists'''
+    @staticmethod
+    def file_exist(file: str):
+        """ Check if the file exists. """
         return os.path.exists(file)
 
-    def Exceptions_dest_lang(self, lang: str):
-        '''Check for destination language'''
+    def exceptions_dest_lang(self, lang: str):
+        """ Check for destination language. """
         try:
             self.translator.translate('Video', dest=lang).text
         except ValueError as Err:
@@ -129,28 +130,27 @@ class Subtitles:
 
 
 def args_flags(args: list):
-    '''Manage flags'''
+    """ Manage flags. """
     flags = []
-
-    if '--color' in args:
-        args.remove('--color')
-        flags.append('--color')
-
-    if '--progress' in args:
-        args.remove('--progress')
-        flags.append('--progress')
-
-    if '--export' in args:
-        args.remove('--export')
-        flags.append('--export')
+    options = [
+        '--color',
+        '--progress',
+        '--export'
+    ]
 
     if len(flags) >= 3:
         usage(1)
+
+    for option in options:
+        if option in args:
+            args.remove(option)
+            flags.append(option)
+
     return flags
 
 
 def check_usage(args: list):
-    '''Checking usage'''
+    """ Checking usage. """
     file_ext = ['.sbv', '.vtt', '.srt']
 
     if not args:
@@ -165,13 +165,13 @@ def check_usage(args: list):
     if args[0] == '--help' or args[0] == '-h' and len(args) == 1:
         usage(status=0)
 
-    # Show all suported languages
+    # Show all supported languages
     if args[0] == '--languages' or args[0] == '-l' and len(args) == 1:
         for key, value in googletrans.LANGUAGES.items():
             print(key, value)
         sys.exit(0)
 
-    # Check for subtitle extention file
+    # Check for subtitle extension file
     if args[0][-4:] not in file_ext:
         usage(status=1)
 
@@ -187,3 +187,7 @@ def main():
     check_usage(args)
     subs = Subtitles(args, flags)
     subs.write_new_subs()
+
+
+if __name__ == '__main__':
+    main()
